.. Copyright 2016-2023 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.bootstrap.navs
-------------------------------

.. sidebar:: Examples in this section

   - (deleted) tutorial.pageflow2bootstrap

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>

.. automodule:: reahl.web.bootstrap.navs

.. uml:: ../../../../reahl-web/reahl/web_dev/bootstrap/menus_and_layout.puml

Nav
"""

.. autoclass:: Nav
   :members:


PillLayout
""""""""""

.. autoclass:: PillLayout
   :members:


TabLayout
"""""""""

.. autoclass:: TabLayout
   :members:

DropdownMenu
""""""""""""

.. autoclass:: DropdownMenu
   :members:

DropdownMenuLayout
""""""""""""""""""

.. autoclass:: DropdownMenuLayout
   :members:

Menu
""""

.. autoclass:: Menu
   :members:
      
